eval 'exec $PERL_PATH/perl -w -S $0 ${1+"$@"}' if 0;  

#

# Force all variables to be declared.  
use strict;


# Import module for command-line inputs.

use Getopt::Std;
my %options = ();
getopts("n:O:i:m:t:P:F:I:",\%options);
#n - namelist;
#O - output directory;
#i - input truth image file name;
#m - PRF Map filename
#T - truth list file name
#P - truth image PRF
#F - the file with pointing for the frames and potentially
#    the distortion coefficients
#I - list of input images

# run mosaic_split to create individual frames
#  out of the truth image and a table of pointings
# run pointsourceimage to populate the individual frames
# with the point sources from the truth list
# run pointsourceimage to populate the truth image

# Get other required libraries.
if (! (defined $ENV{WRAPPER_UTILS})) {
  die "*** Env. var. WRAPPER_UTILS not set; quitting...\n";
}

use lib "$ENV{WRAPPER_UTILS}";

require 'PSEutils.pl';

my $verbose = 1;
my $version = '2.2';
my $iam = "simulate.pl";
my $heading = "Wrapper-script: ${iam}, ".
            "Version $version\n\n".
            "By David Makovoz (davidm\@ipac.caltech.edu)\n".
            "Copyright (C) 2005 California Institute of ".
            "Technology";
 
 if ($verbose) {
    print "=================================================================";
    print "\nWrapper-script $iam, Version $version\n\n";
 }


my $NL_name = $options{"n"} || "simulate.nl";
my $NLpath = my_set_path("SIRTF_CDF","./cdf");
my $NL_file_name = $NLpath.$NL_name;
my @NL_file;
ReadFileIntoList($NL_file_name, \@NL_file, $iam, $verbose);
check_commas(@NL_file);
$verbose = read_namelist( "verbose", 1,@NL_file );

my $OUTPUT_DIR = $options{"O"} ||read_namelist( "OUTPUT_DIR", "", @NL_file );
my $sys_command;

if($OUTPUT_DIR ne "" && !($OUTPUT_DIR =~ /\/$/)){$OUTPUT_DIR .= '/'};
if (! (-e $OUTPUT_DIR)) {
  $sys_command = "mkdir -p $OUTPUT_DIR";
  system($sys_command);
}
# { mkdir $OUTPUT_DIR, 0777;}

my $TRUTH_TABLE = $options{"T"} ||
  read_namelist( "TRUTH_TABLE", "$OUTPUT_DIR"."/extract.tbl", @NL_file );


my $TRUTH_IMAGE_FILE_NAME = $options{"i"} || 
  read_namelist( "TRUTH_IMAGE_FILE_NAME", "", @NL_file );


my $PRFpath = my_set_path("SIRTF_CAL","./cal");


my $PRFMAP_FILE_NAME = $options{"m"} ||
  read_namelist( "PRFMAP_FILE_NAME", "PRF_Map.tbl", @NL_file );

my $PointingTable_file_name = $options{"F"} ||
  read_namelist( "PointingTable_file_name", "", @NL_file );
my $have_pointing_table = 1;
if($PointingTable_file_name eq ""){
  $PointingTable_file_name = $OUTPUT_DIR."header_list.tbl";
  $have_pointing_table = 0;
}

my $Truth_PRF_file_name = $options{"P"} ||
  read_namelist( "TruthImage_PRF_file_name", "", @NL_file );

if( (! (-e $Truth_PRF_file_name)) && ($Truth_PRF_file_name ne "")){
  $Truth_PRF_file_name = $PRFpath.$Truth_PRF_file_name;
}

my $PIXEL_RATIO_X = read_namelist( "PIXEL_RATIO_X", 1, @NL_file );
my $PIXEL_RATIO_Y = read_namelist( "PIXEL_RATIO_Y", 1, @NL_file );


my $NICE = read_namelist( "NICE", 0, @NL_file );
if($NICE){
  $NICE = 19;
}

 # Set auto-flush.
  
select STDERR; $| = 1; select STDOUT; $| = 1;
# common variables
my($status, $input_files,  $output_files, $commandline);

#to do list
my $run_mosaic_split = read_namelist( "split_truth_image", 0,@NL_file );
my $run_pointsource_frames = read_namelist( "insert_pointsources_individual_frames", 0,@NL_file );
my $run_pointsource_truth = read_namelist( "insert_pointsources_truth_image", 0,@NL_file );

my $delete_intermediate_files = read_namelist("delete_intermediate_files",0, @NL_file );
# end of todo list

my $split_dir     = read_namelist( "SPLIT_DIR",     "Split",     @NL_file );
setup_subdir(\$split_dir,$OUTPUT_DIR,$run_mosaic_split);

my $pointfill_dir     = read_namelist( "POINTFILL_DIR",     "Pointfill",     @NL_file );
setup_subdir(\$pointfill_dir,$OUTPUT_DIR,$run_pointsource_frames);

my $split_prefix = $split_dir."split";
my $pointfill_prefix = $pointfill_dir;


my $files_to_delete;
my $output_file_name;
my $i;

my $IMAGE_STACK_FILE_NAME = $options{"I"} ||
  read_namelist( "IMAGE_STACK_FILE_NAME", "", @NL_file );
my $have_image_stack = 1;
if($IMAGE_STACK_FILE_NAME eq ""){
  $have_image_stack = 0;
}

my $BASE_FILE_NAME;
my $split_image_list;
my $pointfill_image_list;

if($have_pointing_table){
   $split_image_list = $split_dir."SplitImageList.txt";
   $pointfill_image_list = $pointfill_dir."PointfillImageList.txt";
}
elsif($have_image_stack){
   $BASE_FILE_NAME = strip_pathname($IMAGE_STACK_FILE_NAME);
   $split_image_list = $split_dir."Split_".$BASE_FILE_NAME;
   $pointfill_image_list = $pointfill_dir."Pointfill_".$BASE_FILE_NAME;
}
else{
  myexit64($iam,"Either pointing table or image stack should be given, quitting",$verbose);
}

my @image_stack;
my $N_Images;
my $input_file_name;

if($have_pointing_table){
  $N_Images = table_lenth($PointingTable_file_name);
}
else{
  ReadFileIntoList($IMAGE_STACK_FILE_NAME, \@image_stack, $iam, $verbose);
  $N_Images = @image_stack;
}
#make lists of images


if($run_mosaic_split){
  open(OUT,">$split_image_list") or 
    myexit64($iam,"Couldn't open $split_image_list; quitting",$verbose);
#  if($have_pointing_table){
  if(1){
    my $truth_image_file_name = strip_pathname($TRUTH_IMAGE_FILE_NAME);
    my $number;
    my @extra = ('000','00','');
    my $index = 0;
    for($i=0;$i<$N_Images;$i++){
      if($i== 10 || $i == 100 || $i == 1000){
	$index++;
      }
      $number = sprintf("%d",$i);
      $number = $extra[$index].$number;
      $output_file_name = $split_prefix."_".$number."_".$truth_image_file_name;
      
      print OUT "$output_file_name\n";  
    }
  }
  else{
    for($i=0;$i<$N_Images;$i++){ 
      chomp ($input_file_name = $image_stack[$i]);
      $output_file_name = $split_prefix.strip_pathname($input_file_name);
      print OUT "$output_file_name\n";  
    }
  }
  close(OUT) or myexit64($iam,"Couldn't close $split_image_list; quitting",$verbose);
}

if($run_pointsource_frames){
  my @split_list = `cat $split_image_list`;
  open(OUT,">$pointfill_image_list") or 
    myexit64($iam,"Couldn't open $pointfill_image_list; quitting",$verbose);
  for($i=0;$i<$N_Images;$i++){ 
    chomp ($output_file_name = $pointfill_prefix.strip_pathname($split_list[$i]) );
    
    print OUT "$output_file_name\n";  
  }
  close(OUT) or myexit64($iam,"Couldn't close $pointfill_image_list; quitting",$verbose);
}
# end make lists of images

#run mosaic_split
if($run_mosaic_split){
  if(!$have_pointing_table){
    #first run the script to create the input file for mosaic_split module
    my $sys_command = " -I $IMAGE_STACK_FILE_NAME -O $PointingTable_file_name";
    print "$sys_command \n";
  if($status = run_script("fiducial_frame.pl ",$sys_command,$verbose)){
    exit($status)};  
  }

  $commandline = "o=$split_prefix";
  $input_files = "i=$TRUTH_IMAGE_FILE_NAME&f=$PointingTable_file_name";
  $output_files = "";
  if($status = run_all("mosaic_split", $input_files,$output_files,$commandline,$verbose-$NICE)){
    exit($status)};  
}

# run pointsourceimage to populate the input frames images
if($run_pointsource_frames){
# Usage: pointsourceimage
#        -n <input_namelist_fname> (Optional)
#        -psx PSImage_Xsize (Optional, alternative is the full PRF size; should be odd)
#        -psy PSImage_Ysize (Optional, alternative is the full PRF size; should be odd)
#        -i ImageListName (Namelist or required)
#        -iu UncertaintyListName (Optionally, if the ratio of pointless/uncertainty is required)
#        -ie InExtractList (Namelist or required)
#        -prfi PRF_Map (Namelist or required)
#        -xname X_Column_Name (optional, default is RA)
#        -yname Y_Column_Name (optional, default is Dec)
#        -fluxname Flux_Column_Name (optional, default is flux)
#        -backname Background_Column_Name (optional, default is bckgrnd)
#        -prfYre PRF_ResampleY_Factor (Namelist or required is PRF IS used)
#        -op Output_PointSourceImage_Prefix (Optional)
#        -opl Output_PointlessImage_Prefix (Optional)
#        -opad Output_PointSourceAddedImage_Prefix (Optional)
#        -orat Output_RatioImage_Prefix (Optional)
#        -radec Input_RA_Dec (Optional)
#        -back Add_Background (Optional)
#        -fif FIF_Filename (Required if Input_RA_Dec is not set.)
#        -refpoint Use_Refined_Pointing (Optional)


  $commandline = "a=&n=$NL_name&log=$NLpath"."/log_pointfill";
  $input_files = "i=$split_image_list&ie=$TRUTH_TABLE&fif=$TRUTH_IMAGE_FILE_NAME";
  $input_files .= "&prfi=$PRFMAP_FILE_NAME";
  $output_files = "opad=$pointfill_prefix";
  if($status = run_all("pointsourceimage", $input_files,$output_files,$commandline,$verbose-$NICE)){
    exit($status)};  
}

# run pointsourceimage to populate the truth image
my $truth_image_list = $OUTPUT_DIR."TruthImage.txt";
my $truth_prf_map = $OUTPUT_DIR."TruthPRFMap.tbl";
# the above have to be faked, since the program
# doesn't accept individual PRFs or individual input files
if($run_pointsource_truth){
write_image_list($truth_image_list,$TRUTH_IMAGE_FILE_NAME);
write_prf_map($truth_prf_map,$Truth_PRF_file_name,$TRUTH_IMAGE_FILE_NAME);


  $commandline = "a=&n=$NL_name&namelist_prefix=TRUTH_&log=$NLpath"."/log_pointfill_truth";
  $input_files = "i=$truth_image_list&ie=$TRUTH_TABLE&fif=$TRUTH_IMAGE_FILE_NAME";
  $input_files .= "&prfi=$truth_prf_map";
  $output_files = "opad=$pointfill_prefix";
  if($status = run_all("pointsourceimage", $input_files,$output_files,$commandline,$verbose-$NICE)){
    exit($status)};  
}



#copy the namelist to the output directory

$sys_command = "cp $NL_file_name $OUTPUT_DIR";
system($sys_command);


print "Wrapper-script $iam terminated normally.\n";



########################################################################################
sub table_lenth{
########################################################################################
  my ($table_file_name)= @_;
  my $iam = "table_length";
  if (! (-e $table_file_name)) {
    myexit64($iam,"file $table_file_name doesn't exist",1);}
  
  my  @file = `cat $table_file_name`;
  my $line;
  my $N_Lines = 0;
  
  for $line (@file){
    if( !($line =~ /^\\/) && !($line =~ /^\|/) ){
      $N_Lines++;
    }
  }
  return $N_Lines;
}

########################################################################################
sub write_image_list{
########################################################################################
my ($imagelist_file_name,$image_file_name) = @_;
open(OUT,">$imagelist_file_name") or die "Couldn't open $imagelist_file_name; quitting\n";
printf OUT "$image_file_name\n";
close(OUT) or die "Couldn't close $imagelist_file_name; quitting\n";
}
