#
#  Script for producing source lists from cleaned images
#
#  Input image filenames are I?_"name".fits
#
#  Output source lists are coo.?
#
#  Works on any of 4 IRAC channels
#
#  FWHM set for 0.8626716"/pix (1.22/sqrt(2))
#
# (c) 2005 Mike Schuster (mschuster@cfa.harvard.edu)
# (c) 2005 SAO - Smithsonian Astrophysical Observatory
#
#  v1.2 - 11 JAN 2006
#  several previous versions by several authors, SAO
#

procedure do_nsfind (filename, dmin1, dmin2, dmin3, dmin4, dmax1, dmax2, dmax3, dmax4, sig1, sig2, sig3, sig4)

string filename
real dmin1
real dmin2
real dmin3
real dmin4
real dmax1
real dmax2
real dmax3
real dmax4
real sig1
real sig2
real sig3
real sig4

begin

  string exfile
  string name
  name = filename

  if (access("coo.1") || access("coo.2") || access("coo.3") || access("coo.4"))
    delete("coo.*",verify-)

  unlearn("daofind")
  unlearn("datapars")
  unlearn("findpars")

  exfile = "I1_"//name//".fits"
  if (access(exfile)) {
    daofind(image=exfile, out="coo.1", veri-, verb-, fw=1.92, sigma=sig1, datami=dmin1, datama=dmax1, thr=4)
  }

  exfile = "I2_"//name//".fits"
  if (access(exfile)) {
    daofind(image=exfile, out="coo.2", veri-, verb-, fw=1.99, sigma=sig2, datami=dmin2, datama=dmax2, thr=4)
  }

  exfile = "I3_"//name//".fits"
  if (access(exfile)) {
    daofind(image=exfile, out="coo.3", veri-, verb-, fw=2.18, sigma=sig3, datami=dmin3, datama=dmax3, thr=4)
  }

  exfile = "I4_"//name//".fits"
  if (access(exfile)) {
    daofind(image=exfile, out="coo.4", veri-, verb-, fw=2.30, sigma=sig4, datami=dmin4, datama=dmax4, thr=4)
  }

end
