#
#  Script for producing photometry from cleaned images
#  using extracted source lists xycoo.? produced by
#  do_nsfind.cl, psort_xy.cl, and pdump_xy.cl
#
#  Input image filenames are I?_"name".fits
#  Input coordinate lists are xycoo.?
#
#  Output IRAF photometry lists are mag.?
#
#  Works on any of 4 IRAC channels
#
#  FWHM set for 0.8626716"/pix (1.22/sqrt(2))
#  Aperture set for 4 pix (~3 native IRAC pix)
#  Annulus set for 14.1 pix (10 native IRAC pix)
#  Annulus width set for 14.1 pix (10 native IRAC pix)
#  Zero-points are set for DN/s and apertures described
#
# (c) 2005 Mike Schuster (mschuster@cfa.harvard.edu)
# (c) 2005 SAO - Smithsonian Astrophysical Observatory
#
#  v1.2 - 11 JAN 2006
#  several previous versions by several authors, SAO
#

procedure do_nsphot (filename, scale1, scale2, scale3, scale4, dmin1, dmin2, dmin3, dmin4, dmax1, dmax2, dmax3, dmax4, sig1, sig2, sig3, sig4)

string filename
real scale1
real scale2
real scale3
real scale4
real dmin1
real dmin2
real dmin3
real dmin4
real dmax1
real dmax2
real dmax3
real dmax4
real sig1
real sig2
real sig3
real sig4

begin

  string exfile
  string name
  name = filename

  if (access("mag.1") || access("mag.2") || access("mag.3") || access("mag.4"))
    delete("mag.*",verify-)

  unlearn("phot")
  unlearn("datapars")
  unlearn("centerpars")
  unlearn("fitskypars")
  unlearn("photpars")

  exfile = "I1_"//name//".fits"
  if (access(exfile) && access("xycoo.1")) {
    phot(image=exfile, co="xycoo.1", out="mag.1", interact-, veri-, fw=1.92, sigm=sig1, datami=dmin1, datama=dmax1, epadu=scale1, calgo="none", salgo="mode", an=14.1, dan=14.1, ap=4, z=19.483)
  }

  exfile = "I2_"//name//".fits"
  if (access(exfile) && access("xycoo.2")) {
    phot(image=exfile, co="xycoo.2", out="mag.2", interact-, veri-, fw=1.99, sigm=sig2, datami=dmin2, datama=dmax2, epadu=scale2, calgo="none", salgo="mode", an=14.1, dan=14.1, ap=4, z=18.795)
  }

  exfile = "I3_"//name//".fits"
  if (access(exfile) && access("xycoo.3")) {
    phot(image=exfile, co="xycoo.3", out="mag.3", interact-, veri-, fw=2.18, sigm=sig3, datami=dmin3, datama=dmax3, epadu=scale3, calgo="none", salgo="mode", an=14.1, dan=14.1, ap=4, z=16.737)
  }

  exfile = "I4_"//name//".fits"
  if (access(exfile) && access("xycoo.4")) {
    phot(image=exfile, co="xycoo.4", out="mag.4", interact-, veri-, fw=2.30, sigm=sig4, datami=dmin4, datama=dmax4, epadu=scale4, calgo="none", salgo="mode", an=14.1, dan=14.1, ap=4, z=17.157)
  }

end
