#
# This simple IRAF script that allows one to inspect a number 
# of images rapidly and select those to be used in the next 
# stage of processing.
#
# The program can look at a list of files.
#
# usage: cl> inspect ../Lists/bcd_I1.lis
#
# This variant reads the bad pixel mask and flags those pixels 
# in red on the display. Note: the "@" should NOT be included 
# before the list.
#
#
# February 19, 2003  Brian M. Patten
# Smithsonain Astrophysical Observatory
# 
# Mike Schuster
# mschuster@cfa.harvard.edu
# Modified 27 MAR 2006
#

procedure inspect (fname)

string  fname
struct  *list

begin

 string  temp
 string  image
 string  junk
 string  backup

 temp = mktemp ("tmp$lim")
 files ("@"//fname, >temp)

 image = ""
 list = temp
 print ("Image Inspection -- Version 1.1")
 print (" ")

 # set backup filename
 backup = fname//".orig"
 if (access(backup))
  delete(backup,verify-)

 print ("A back-up of your image list has been created: "//backup)
 print (" ")


 # make revised list
 if (access(fname))
  delete(fname,verify-)
 while (fscan (list, image) != EOF) {
  print ("Working on image: ",image)
  print (image, >> backup)
  junk = "n"
  unlearn display
  display (image,frame=1,bpdisplay="overlay",bpm="BPM",bpcolors="1=red")
  unlearn imstatistics
  imstat(image//"[79:178,79:178]", fields = "image,max", format-)
  print ("Use this image in processing? [y n]")
  scanf ("%c",junk)
  if (junk == "y") {
   print (image, >> fname)
  }
  print (" ")
 }

end
